@@ -219,7 +219,7 @@ class IDrone(IRobot, abc.ABC):
         self.camera_pitch_motor.setPosition(-0.1 * pitch_acceleration)
 
         # Get input
-        if self.battery.remaining_energy_percentage <= 0.9:
+        if self.battery.remaining_energy_percentage <= self.battery.safe_landing_percentage:
             roll_disturbance, pitch_disturbance, yaw_disturbance = 0, 0, 0
             self.target_altitude -= 0.05
             print('Safe landing')
