@@ -34,33 +34,30 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             f_led.set(led_on)
             led_on = not led_on
 
-    def get_processing_energy(self):
+    def get_processing_energy(self, start_flight_time):
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
         probe_cpu_time = self.probe.get_metric('ProcessCpuTimeMetric')
         probe_io_time = self.probe.get_metric('ProcessIOTimeMetric')
 
         cpu_time = probe_cpu_time.get_val()
-        flight_time = probe_alive_time.get_val()
+        flight_time = time.time() - start_flight_time
         t = probe_io_time.get_val()
         io_time = 0 if t is None else t
 
         return self.energy_model.processing_energy.calculate(cpu_time_active=cpu_time, flight_time=flight_time, io_time=io_time)
 
-    def get_communication_energy(self, comm_transmit_time, comm_receive_time):
-
+    def get_communication_energy(self, start_flight_time, comm_transmit_time, comm_receive_time):
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
-        flight_time = probe_alive_time.get_val()
+        flight_time = time.time() - start_flight_time
         return self.energy_model.communication_energy.calculate(transmit_time=comm_transmit_time, receive_time=comm_receive_time, idle_time=flight_time-(comm_transmit_time + comm_receive_time))
 
-    def get_motor_energy(self):
+    def get_motor_energy(self, start_flight_time):
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
-        flight_time = probe_alive_time.get_val()
+        flight_time = time.time() - start_flight_time
         return self.energy_model.motor_energy.calculate(hovering_time=flight_time)
 
     def run(self):
         # Wait a second before starting
-
-
         while self.step(self.basic_time_step) != -1:
             if self.getTime() > 1:
                 break
@@ -78,7 +75,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
         comm_transmit_time = 0
         comm_receive_time = 0
+        inference_time = 0
 
+        start_flight_time = time.time()
         while self.step(self.basic_time_step) != -1:
 
             if self.getTime() > 600:
@@ -98,7 +97,11 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Execute prediction pipeline step
             if self.model is not None:
+                t1 = time.time()
                 prediction = self.model.predict()
+                t2 = time.time()
+                inference_time += t2 - t1
+
                 # t1 = time.time()
                 # self.send_msg(msg=str(prediction), emitter_devices=emitter_devices)
                 # t2 = time.time()
@@ -108,9 +111,11 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
                     print(prediction)
 
             # Get energy values on each cycle
-            energy = {**self.get_processing_energy(),
-                      **self.get_communication_energy(comm_transmit_time=comm_transmit_time, comm_receive_time=comm_receive_time),
-                      **self.get_motor_energy(), 'simulation_time_s': self.getTime()}
+            energy = {**self.get_processing_energy(start_flight_time=start_flight_time),
+                      **self.get_communication_energy(start_flight_time=start_flight_time, comm_transmit_time=comm_transmit_time, comm_receive_time=comm_receive_time),
+                      **self.get_motor_energy(start_flight_time=start_flight_time), 'simulation_time_s': self.getTime(),
+                      'cpu_time_s': self.probe.get_metric('ProcessCpuTimeMetric').get_val(),
+                      'inference_time_s': inference_time}
 
             energy['total_energy'] = energy['e_proc'] + energy['e_comm'] + energy['e_motor']
 
@@ -122,7 +127,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Update log data every 5 minutes with energy values
             print(energy, f'\n{self.battery.remaining_energy_percentage * 100}% battery remaining')
-            with open('logs/ML_on_station.json', 'a+') as logfile:
+            with open('logs/Crowd_Detection_on_drone_no_flight_probe.json', 'a+') as logfile:
                 json.dump(energy, logfile)
                 logfile.write('\n')
 
